@@ -6,6 +6,7 @@ from .api_handler import default_api
 class Entity(object):
     """Base entity abstraction with common methods to update and push data the the API
     """
+    pk = None
 
     def __init__(self, _id, _data=None, api=None, update_threshold=30):
         """Base entity initialization
@@ -31,12 +32,26 @@ class Entity(object):
         else:
             self._last_updated = time.time()
 
-    def _make_url(self):
+    @property
+    def url_base(self):
         """Makes the base url for each entity and uses it for api requests.
-        Needs to be overwritten on each subclass
+        This URL will be used for GET (entities listings) and POST requests.
+        Needs to be overwritten on each subclass.
+
+        E.g for devices: /accounts/A1234/devices
         """
         raise NotImplementedError()
 
+    @property
+    def url_id(self):
+        """Makes the url with the Entity id for each entity and uses it for api requests.
+        This URL will be used for GET (entity attributes) and PUT requests.
+        Needs to be overwritten on each subclass
+
+        E.g for devices: /accounts/A1234/devices/D1234
+        """
+        return '{}/{}'.format(self.url_base, self._id)
+
     def should_update(self):
         if self._update_threshold is None:
             return False
@@ -70,7 +85,7 @@ class Entity(object):
         """
         if data is None:
             data = self._data
-        self.api.call("PUT", self._make_url(), data=data, **api_call_kwargs)
+        self.api.call("PUT", self.url_id, data=data, **api_call_kwargs)
 
     def update(self, api_call_kwargs={}):
         """Synchronizes device properties with the Freedom API server.
@@ -78,7 +93,7 @@ class Entity(object):
         Args:
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
-        self._data = self.api.call("GET", self._make_url(), **api_call_kwargs)
+        self._data = self.api.call("GET", self.url_id, **api_call_kwargs)
         self._last_updated = time.time()
 
     def __repr__(self):
