@@ -1,8 +1,12 @@
+import re
 import time
 import logging
 
+date_short_relative_regex = re.compile(r'^[+-]\d+[smdhwMY]$')
+
 logger = logging.getLogger(__name__)
 
+
 def to_struct_time(t):
     """Converts a UNIX time, a time string, or a struct_time to a struct_time.
     """
@@ -22,6 +26,15 @@ def to_struct_time(t):
     logger.debug("parse_time: could not parse time: ", t)
     return None
 
+
+def to_time_query_param(value):
+    """Parse value to API time query parameter"""
+    if isinstance(value, str) and is_short_relative_date(value):
+        return value
+    else:
+        return to_unix_time(value)
+
+
 def to_unix_time(t):
     """Converts a UNIX time, a time string, or a struct_time to a UNIX time.
     """
@@ -40,3 +53,17 @@ def to_unix_time(t):
 
     logger.debug("parse_time: could not parse time: ", t)
     return None
+
+
+def is_short_relative_date(value):
+    """Checks if the value matches with short relative dates used for API time ranges
+    Examples:
+    * 25s: 25 seconds
+    * 10m: 10 minutes
+    * 3h: 3 hours
+    * 5d: 5 days
+    * 1w: 1 week
+    """
+    if value.lower() == 'now':
+        return True
+    return date_short_relative_regex.match(value) is not None
